@@ -1,5 +1,5 @@
 """Module of Saver"""
-from typing import Any, Dict, Union
+from typing import Any, Dict, Union, Optional
 import os
 import logging
 import shutil
@@ -14,8 +14,8 @@ import yaml
 from .io import rotateItems
 from .config import serialize
 from .logger import configLogging
-
-StrPath = Union[str, os.PathLike[str]]
+from .types import StrPath
+from .runtime import relativePath
 
 __all__ = [
     "Saver"
@@ -77,7 +77,7 @@ class Saver(SummaryWriter):
         self.Logger = logger
 
         self._savePath = os.path.join(self._saveDir, saveName)
-        self.debug("Saver located at %s", self._saveDir)
+        self.debug("Saver located at %s", relativePath(self._saveDir))
 
 
         if config is not None:
@@ -112,85 +112,15 @@ class Saver(SummaryWriter):
     def Logger(self, logger: logging.Logger):
         logger = logger or logging
         self._logger = logger
-
-    def setLevel(self, level):
-        """
-        Set the logging level of this logger.  level must be an int or a str.
-        """
-        self._logger.setLevel(level)
-
-    def debug(self, msg, *args, **kwargs):
-        """
-        Log 'msg % args' with severity 'DEBUG'.
-
-        To pass exception information, use the keyword argument exc_info with
-        a true value, e.g.
-
-        logger.debug("Houston, we have a %s", "thorny problem", exc_info=1)
-        """
-        self._logger.debug(msg, *args, **kwargs)
-
-    def info(self, msg, *args, **kwargs):
-        """
-        Log 'msg % args' with severity 'INFO'.
-
-        To pass exception information, use the keyword argument exc_info with
-        a true value, e.g.
-
-        logger.info("Houston, we have a %s", "interesting problem", exc_info=1)
-        """
-        self._logger.info(msg, *args, **kwargs)
-
-    def warning(self, msg, *args, **kwargs):
-        """
-        Log 'msg % args' with severity 'WARNING'.
-
-        To pass exception information, use the keyword argument exc_info with
-        a true value, e.g.
-
-        logger.warning("Houston, we have a %s", "bit of a problem", exc_info=1)
-        """
-        self._logger.warning(msg, *args, **kwargs)
-
-    def error(self, msg, *args, **kwargs):
-        """
-        Log 'msg % args' with severity 'ERROR'.
-
-        To pass exception information, use the keyword argument exc_info with
-        a true value, e.g.
-
-        logger.error("Houston, we have a %s", "major problem", exc_info=1)
-        """
-        self._logger.error(msg, *args, **kwargs)
-
-    def exception(self, msg, *args, exc_info=True, **kwargs):
-        """
-        Convenience method for logging an ERROR with exception information.
-        """
-        self._logger.error(msg, *args, exc_info=exc_info, **kwargs)
-
-    def critical(self, msg, *args, **kwargs):
-        """
-        Log 'msg % args' with severity 'CRITICAL'.
-
-        To pass exception information, use the keyword argument exc_info with
-        a true value, e.g.
-
-        logger.critical("Houston, we have a %s", "major disaster", exc_info=1)
-        """
-        self._logger.critical(msg, *args, **kwargs)
-
-    def log(self, level, msg, *args, **kwargs):
-        """
-        Log 'msg % args' with the integer severity 'level'.
-
-        To pass exception information, use the keyword argument exc_info with
-        a true value, e.g.
-
-        logger.log(level, "We have a %s", "mysterious problem", exc_info=1)
-        """
-        self._logger.log(level, msg, *args, **kwargs)
-
+        self.setLevel = self._logger.setLevel
+        self.debug = self._logger.debug
+        self.info = self._logger.info
+        self.warning = self._logger.warning
+        self.warn = self._logger.warn
+        self.error = self._logger.error
+        self.exception = self._logger.exception
+        self.critical = self._logger.critical
+        self.log = self._logger.log
 
     def _dumpFile(self, path: StrPath):
         shutil.copytree(path, os.path.join(self._saveDir, "dump"), symlinks=True, ignore=lambda src, path: [x for x in path if x == "__pycache__"], ignore_dangling_symlinks=True)
@@ -236,7 +166,7 @@ class Saver(SummaryWriter):
         self.debug("Successfully saved checkpoint with keys: %s", list(saveDict.keys()))
 
     @staticmethod
-    def load(filePath: StrPath, mapLocation: Dict[str, str] = None, strict: bool = True, logger: Logger = None, **objs: Any) -> Dict[str, Any]:
+    def load(filePath: StrPath, mapLocation: Dict[str, str] = None, strict: bool = True, logger: Optional[Union[logging.Logger, "Saver"]] = None, **objs: Any) -> Dict[str, Any]:
         """Load from ckpt.
 
         Args:
@@ -269,7 +199,7 @@ class Saver(SummaryWriter):
 
 
 class DummySaver(Saver):
-    def __init__(self, saveDir: StrPath, saveName: StrPath = "saved.ckpt", loggerName: str = "root", loggingLevel: str = "INFO", config: Any = None, autoManage: bool = True, maxItems: int = 25, reserve: bool = False, dumpFile: str = None):
+    def __init__(self, saveDir: StrPath, saveName: StrPath = "saved.ckpt", loggerName: str = "root", loggingLevel: str = "INFO", config: Any = None, autoManage: bool = True, maxItems: int = 25, reserve: bool = False, dumpFile: str = None, activateTensorboard: bool = False):
         if saveDir.endswith(self.NewestDir):
             autoManage = False
         if autoManage:
@@ -320,5 +250,17 @@ class DummySaver(Saver):
         raise NotImplementedError("Dummy saver does not implement `save` function.")
 
     @staticmethod
-    def load(filePath: StrPath, mapLocation: Dict[str, str] = None, strict: bool = True, logger: Logger = None, **objs: Any) -> Dict[str, Any]:
-        raise NotImplementedError("Dummy saver does not implement `load` function.")
+    def load(filePath: StrPath, mapLocation: Dict[str, str] = None, strict: bool = True, logger: logging.Logger = None, **objs: Any) -> Dict[str, Any]:
+        savedDict = torch.load(filePath, map_location=mapLocation)
+        for key, value in objs.items():
+            stateDict = savedDict[key]
+            if isinstance(value, torch.nn.Module):
+                value.load_state_dict(stateDict, strict=strict)
+            elif callable(getattr(value, "load_state_dict", None)):
+                value.load_state_dict(stateDict)
+            else:
+                if isinstance(value, torch.Tensor):
+                    value.data = stateDict
+                else:
+                    objs[key] = stateDict
+        return objs
